{% load pages_tags cache %}
{% if page.status %}
<li>
<a href="{% show_absolute_url page %}">{% show_content page "slug" %}</a> <span style="color:#999">{% ifequal page current_page %}selected{% endifequal %}</span>
    {% if children %}
    <ul>
    {% for child in children %}
        {% pages_menu child %}
    {% endfor %}
    </ul>
    {% endif %}
</li>
{% endif %}
