/*
 * WYMeditor : what you see is What You Mean web-based editor
 * Copyright (c) 2008 Jean-Francois Hovinne, http://www.wymeditor.org/
 * Dual licensed under the MIT (MIT-license.txt)
 * and GPL (GPL-license.txt) licenses.
 *
 * For further information visit:
 *      http://www.wymeditor.org/
 *
 * File Name:
 *      skin.css
 *      main stylesheet for the minimal WYMeditor skin
 *      See the documentation for more info.
 *
 * File Authors:
 *      Jean-Francois Hovinne
 *      Scott Lewis (see Silver skin)
*/

/* Set iframe */
.wym_skin_minimal div.wym_iframe iframe {
    width: 90%;
    height: 200px;
}

/* Hide h2 by default */
.wym_skin_minimal h2 {
    display: none;
}

/* Show specific h2 */
.wym_skin_minimal div.wym_tools h2,
.wym_skin_minimal div.wym_containers h2,
.wym_skin_minimal div.wym_classes h2 {
    display: block;
}

.wym_skin_minimal div.wym_section ul {
    margin: 0;
}

.wym_skin_minimal div.wym_section ul li {
    float: left;
    list-style-type: none;
    margin-right: 5px;
}

.wym_skin_minimal div.wym_area_top,
.wym_skin_minimal div.wym_area_right,
.wym_skin_minimal div.wym_containers,
.wym_skin_minimal div.wym_classes {
    float: left;
}

.wym_skin_minimal div.wym_area_main {
    clear: both;
}

.wym_skin_minimal div.wym_html {
    width: 90%;
}

.wym_skin_minimal textarea.wym_html_val {
    width: 100%;
    height: 100px;
}

/* DROPDOWNS (see Silver skin) */
.wym_skin_minimal div.wym_dropdown {
  cursor: pointer;
  margin: 0px 4px 10px 0px;
  padding: 0px;
  z-index: 1001;
  display: block;
}

.wym_skin_minimal div.wym_dropdown ul {
  display: none;
  width: 124px;
  padding: 0px;
  margin: 0px;
  list-style-type: none;
  list-style-image: none;
  z-index: 1002;
  position: absolute;
  border-top: 1px solid #AAA;
}

.wym_skin_minimal div.wym_dropdown ul li {
  width: 146px;
  height: 20px;
  padding: 0px;
  margin: 0px;
  border: 1px solid #777;
  border-top: none;
  background: #EEE;
  list-style-image: none;
}

.wym_skin_minimal div.wym_dropdown h2 {
  width: 138px;
  height: 16px;
  color: #000;
  background-image: url(images/bg.selector.silver.gif);
  background-position: 0px -18px;
  background-repeat: no-repeat;
  border: none;
  font-family: "Trebuchet MS", Verdana, Arial, Helvetica, Sanserif;
  font-size: 12px;
  font-weight: bold;
  padding: 2px 0px 0px 10px;
  margin: 0px;
}

.wym_skin_minimal div.wym_dropdown a {
  text-decoration: none;
  font-family: "Trebuchet MS", Verdana, Arial, Helvetica, Sanserif;
  font-size: 12px;
  padding: 5px 0px 0px 10px;
  display: block;
  width: 136px;
  height: 15px;
  color: #000;
  text-align: left;
  margin-left: 0px;
}

.wym_skin_minimal div.wym_dropdown a:hover {
  background: #BBB;
  border-bottom: none;
}
