WYMeditor.STRINGS['nn'] = {
    Strong:           'Feit',
    Emphasis:         'Utheva',
    Superscript:      'Opphøgd',
    Subscript:        'Nedsenka',
    Ordered_List:     'Nummerert liste',
    Unordered_List:   'Punktliste',
    Indent:           'Rykk inn',
    Outdent:          'Rykk ut',
    Undo:             'Angre',
    Redo:             'Gjentaka',
    Link:             'Lenkje',
    Unlink:           'Ta bort lenkja',
    Image:            'Bilete',
    Table:            'Tabell',
    HTML:             'HTML',
    Paragraph:        'Avsnitt',
    Heading_1:        'Overskrift 1',
    Heading_2:        'Overskrift 2',
    Heading_3:        'Overskrift 3',
    Heading_4:        'Overskrift 4',
    Heading_5:        'Overskrift 5',
    Heading_6:        'Overskrift 6',
    Preformatted:     'Preformatert',
    Blockquote:       'Sitat',
    Table_Header:     'Tabelloverskrift',
    URL:              'URL',
    Title:            'Tittel',
    Alternative_Text: 'Alternativ tekst',
    Caption:          'Overskrift',
    Summary:          'Samandrag',
    Number_Of_Rows:   'Tal på rader',
    Number_Of_Cols:   'Tal på kolonnar',
    Submit:           'Ok',
    Cancel:           'Avbryt',
    Choose:           'Vel',
    Preview:          'Førehandsvis',
    Paste_From_Word:  'Lim inn frå Word',
    Tools:            'Verkty',
    Containers:       'Formatering',
    Classes:          'Klassar',
    Status:           'Status',
    Source_Code:      'Kjeldekode'
};

