{% extends "pages/index.html" %}
{% load pages_tags %}

{% block title %}Nice template{% endblock %}

{% block content %}{{ block.super }}
<div style="width:70%">
    <div>fancy content
        <div id="fancy-content" class="placeholder">
            {% placeholder fancy-content with markItUpMarkdown %}
        </div>
    </div>
    {% placeholder right-column with Textarea parsed as right_column %}
</div>

{% endblock %}




